{ config, ... }:
{
  # Allow forwarding
  boot.kernel.sysctl."net.ipv4.ip_forward" = 1;

  # Configure firewall
  networking = {
    firewall = {
      allowPing = false;
      extraInputRules = ''
        ip saddr { ${config.ips.localSpan}.0/24, ${config.ips.wgSpan}.0/24 } tcp dport 2049 accept comment "Accept NFS"
        ip saddr { ${config.ips.pc}, ${config.secrets.lunaIP}, ${config.secrets.cornIP} } tcp dport { 1935, 1945 } accept comment "Accept RTMP"
      '';
    };
  
    # Enable nftables and forwarding
    nftables = {
      tables = {
        forwarding = {
          family = "ip";
          content = ''
            chain PREROUTING {
              type nat hook prerouting priority dstnat; policy accept;
              tcp dport 2211 dnat to ${config.ips.pc}:22 comment "SSH to PC"
              tcp dport 2222 dnat to ${config.ips.wgSpan}.19:22 comment "SSH to Oracle VM"
              
              udp dport { 27005, 27015, 7777 } dnat to ${config.ips.pc} comment "PC Hosted Games"
              
              tcp dport { 58010, 57989, 57984 } dnat to ${config.ips.pc} comment "PC Sunshine TCP"
              udp dport { 57998, 57999, 58000 } dnat to ${config.ips.pc} comment "PC Sunshine UDP"
              
              tcp dport { 38010, 37989, 37984 } dnat to ${config.ips.vm} comment "VM Sunshine TCP"
              udp dport { 37998, 37999, 38000 } dnat to ${config.ips.vm} comment "VM Sunshine UDP"
              
              udp dport { 7790, 7791, 7792 } dnat to ${config.ips.hx} comment "Deus Ex"
              
              ip saddr ${config.secrets.cornIP} tcp dport { 9943, 9944 } dnat to ${config.ips.vm} comment "VM ALVR TCP"
              ip saddr ${config.secrets.cornIP} udp dport { 9943, 9944 } dnat to ${config.ips.vm} comment "VM ALVR UDP"
            }

            chain POSTROUTING {
              type nat hook postrouting priority 100; policy accept;
              oifname "${config.ips.netInt}" masquerade
            }
          '';
        };
      };
    };
  };
}
